document.addEventListener('DOMContentLoaded', () => {
  const themeToggle = document.getElementById('themeToggle');
  const addBoardBtn = document.getElementById('addBoardBtn');
  const boardsContainer = document.getElementById('boardsContainer');
  const taskModal = document.getElementById('taskModal');

  // Theme Toggle
  themeToggle.addEventListener('click', () => {
    document.body.dataset.theme = document.body.dataset.theme === 'dark' ? 'light' : 'dark';
    themeToggle.querySelector('.mode-icon').textContent = 
      document.body.dataset.theme === 'dark' ? '☀️' : '🌙';
  });

  // Drag and Drop
  let draggedTask = null;

  document.addEventListener('dragstart', (e) => {
    if (e.target.classList.contains('task')) {
      draggedTask = e.target;
      e.target.style.opacity = '0.5';
    }
  });

  document.addEventListener('dragend', (e) => {
    if (e.target.classList.contains('task')) {
      e.target.style.opacity = '1';
    }
  });

  document.addEventListener('dragover', (e) => {
    e.preventDefault();
  });

  document.addEventListener('drop', (e) => {
    e.preventDefault();
    const dropTarget = e.target.closest('.active-tasks');
    if (dropTarget && draggedTask) {
      dropTarget.appendChild(draggedTask);
    }
  });

  // Add New Board
  addBoardBtn.addEventListener('click', () => {
    const newBoard = document.createElement('div');
    newBoard.className = 'board';
    newBoard.innerHTML = `
      <div class="board-header">
        <h2 contenteditable="true">New Board</h2>
        <button class="delete-board" aria-label="Delete board">×</button>
      </div>
      <div class="tasks-container">
        <div class="add-task">
          <button class="add-task-btn">+ Add Task</button>
        </div>
        <div class="active-tasks"></div>
        <div class="completed-section">
          <button class="completed-toggle">
            Completed Tasks <span class="completed-count">(0)</span>
          </button>
          <div class="completed-tasks hidden"></div>
        </div>
      </div>
    `;
    boardsContainer.appendChild(newBoard);
  });

  // Delete Board
  boardsContainer.addEventListener('click', (e) => {
    if (e.target.classList.contains('delete-board')) {
      e.target.closest('.board').remove();
    }
  });

  // Task Modal
  document.addEventListener('click', (e) => {
    if (e.target.classList.contains('add-task-btn')) {
      taskModal.classList.remove('hidden');
    }
  });

  document.getElementById('cancelTask').addEventListener('click', () => {
    taskModal.classList.toggle('hidden');
  });

  // Create Task
  document.getElementById('taskForm').addEventListener('submit', (e) => {
    e.preventDefault();
    const taskName = document.getElementById('taskName').value;
    const taskDesc = document.getElementById('taskDesc').value;
    const taskDate = document.getElementById('taskDate').value;
    const taskColor = document.getElementById('taskColor').value;
    const taskLabels = document.getElementById('taskLabels').value;

    const task = createTask(taskName, taskDesc, taskDate, taskColor, taskLabels);
    const activeTasksContainer = document.querySelector('.active-tasks');
    activeTasksContainer.appendChild(task);
    
    taskModal.classList.add('hidden');
    e.target.reset();
  });
});

function createTask(name, desc, date, color, labels) {
  const task = document.createElement('div');
  task.className = 'task';
  task.draggable = true;
  task.style.borderLeftColor = color;
  
  const labelArray = labels.split(',').map(label => label.trim()).filter(Boolean);
  const labelHtml = labelArray.map(label => 
    `<span class="task-label">${label}</span>`
  ).join('');

  task.innerHTML = `
    <div class="task-header">
      <input type="checkbox" class="task-checkbox">
      <div class="task-content">
        <h3>${name}</h3>
        <p>${desc}</p>
        ${date ? `<p class="task-date">Due: ${date}</p>` : ''}
        <div class="task-labels">${labelHtml}</div>
      </div>
    </div>
  `;

  task.querySelector('.task-checkbox').addEventListener('change', (e) => {
    if (e.target.checked) {
      const completedTasks = task.closest('.board')
        .querySelector('.completed-tasks');
      completedTasks.appendChild(task);
      updateCompletedCount(task.closest('.board'));
    }
  });

  return task;
}

function updateCompletedCount(board) {
  const count = board.querySelector('.completed-tasks').children.length;
  board.querySelector('.completed-count').textContent = `(${count})`;
}
